
;;
;; sigma documentation for the Chicken Scheme module system.
;;
;; This program is free software: you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation, either version 3 of the
;; License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; A full copy of the GPL license can be found at
;; <http://www.gnu.org/licenses/>.
;;
;;


(use eggdoc)

(define doc
  `((eggdoc:begin

     (name "sigma")

     (description "Image gallery generator.")

     (author (url "http://chicken.wiki.br/users/ivan-raikov" "Ivan Raikov"))

     (history
      (version "1.20" "Command-line handling converted to using getopt-long")
      (version "1.19" "Bug fix in command-line handling")
      (version "1.18" "Bug fix in filter-subfolders")
      (version "1.17" "Ported to Chicken 4")
      (version "1.16" "Using compiled regular expressions with find-files")
      (version "1.15" "Added some error checking for temporary directory creation")
      (version "1.14" "Another bug fix in directory path escaping")
      (version "1.12" "Bug fix in directory path escaping")
      (version "1.11" "Bug fix to prevent recursive descent into target album dir")
      (version "1.10" "Eliminated use of fmt-num")
      (version "1.9" "Bug fix in image-size")
      (version "1.8" "Bug fix in use of fmt library")
      (version "1.7" "Added support for CD image generation")
      (version "1.6" "Bug fix in the highlights index generation")
      (version "1.5" "Documentation updates")
      (version "1.4" "Added support for highlights functionality")
      (version "1.3" "Bug fix in image directory reading")
      (version "1.2" "Added commands interface")
      (version "1.1" "Bug fix in the meta file; ability to specify captions for subfolders")
      (version "1.0" "Initial release"))

     (requires (url "getopt-long.html" "getopt-long")
	       (url "sxml-transforms.html" "sxml-transforms")
	       (url "utf8.html" "utf8")
	       (url "uri.html" "uri")
	       (url "fmt.html" "fmt"))

     (usage "sigma [options...] [commands...]")
     (download "sigma.egg")

      (documentation

       (p (tt "sigma") " is a simple program for creating a Web gallery
 of images with a single command. It is based on the igal program by
 Eric Pop and generates a set of HTML 4.0+CSS-compliant static slides.
 The appearance of the image gallery can be altered by modifying the
 default CSS file, as well as the slide template and index page
 template files that appear in the image directory. Unlike igal, the
 templates are written as S-expressions, and follow the conventions of
 SXML.")

       (p (tt "sigma") " also checks for the existence of a $HOME/.sigma
 directory where users can store their own templates, overriding the
 site-wide /usr/share/sigma. ")


      (p (tt "sigma") " relies on the ImageMagick package, and if
sorting by image date is desired, it can use the " (tt "exif") "
program to extract EXIF date information from JPEG files.  The " (tt "convert") 
" command from the ImageMagick package is required to process image
files and the " (tt "identify") " command enables " (tt "sigma") " to
include size information in the HTML it generates and to determine
whether large images need to be rescaled. ")

      (p "If the -c option is used, " (tt "sigma") " creates a " (tt ".captions")
" file, which contains captions to be inserted under each slide. "
"The captions must be in S-expression format and may include SXML tags. "
"Each caption entry can be in one of two forms: "
(ol 
 (li (tt "(fname caption [option1 option2 ...])")
     (p "The first element is the image file name, and the second element is the caption. "
	"The file name and the caption are required. They can be followed by any number of "
	"options keywords. The only option keyword currently recognized is " (tt "hl") 
	", which  indicates that the slide should be included on the optional highlights page. "))
 (li  (tt "(subdir name caption) ")
      (p "Entries of this form  be used to specify captions for subfolders. ")))

"To add any comments to this file or to exclude any images from the slide "
"show, add a semicolon the beginning of their respective lines. "
"You may also change the order of images in your slide show at this time. ")

      (subsection "Commands"
	  (p
	   (symbol-table
	    (describe "gallery"   "Create an image gallery (default if no command given)")
	    (describe "thumbs"    "Create image thumbnails (implicit when gallery is also given)")
	    (describe "sort"      "Sort images by EXIF date or file creation date")
	    (describe "cdimage"   "Create a CD image containing the image slides")
	    (describe "clean"     "Clean generated files"))))

      (subsection "Options"
	  (p
	       (symbol-table
		(describe "-a"                 "write image sizes under thumbnails on index page")
		(describe "-c"                 "first generate and then use captions")
		(describe "-C"                 "like -c, but preserve file names as captions")
		(describe "-d DIR"             "operate on files in directory DIR (default: .)")
		(describe "-f"                 "force thumbnail regeneration and scaled slides")
		(describe "-g TITLE"           "gallery title (default: Default Gallery Title)")
		(describe "-k"                 "use the image captions for the HTML slide titles")
		(describe "-R"                 "recursively descend subdirectories")
		(describe "-t DIR"             ("place gallery files in directory DIR "
						"(will be created if it doesn't exist)"))
		(describe "-u"                 "write captions under thumbnails on index page")
		(describe "-U"                 "write slide names under thumbnails on index page")
		(describe "-x"                 "omit the image count from the captions")
		(describe "-y N"               "scale all thumbnails to the same height  (default: 75)")
		(describe "--ad"               "like -a, but write only the image dimensions")
		(describe "--as"               "like -a, but write only the file size (in kbytes)")
		(describe "--author=AUTHOR"    "specify author name (default: $USER)")
		(describe "--con=OPTS"         ("options to pass to " (tt "convert")))
		(describe "--cd-dir=DIR"       "directory for CD image output (default: $HOME/tmp)")
		(describe "--cd-file=DIR"      "name of CD image file if --gcd is not specified (default: Photos)")
		(describe "--gcd=TITLE"        "like -g, but also sets CD image file name")
		(describe "--hls"              "creates a highlights page")
                (describe "--hls-main"         "creates a highlights page as the main page")
		(describe "--html-ext=SUFFIX"  "suffix of output HTML files (default: html)")
		(describe "--html-index=NAME"  "name (without suffix) of the main thumbnail index file (default: index)")
		(describe "--html-hindex=NAME" "name (without suffix) of the highlights index file (default: hindex)")
		(describe "--in"               "use image file names for the HTML slide files")
		(describe "--top"              "create index pages for directories that only contain subfolders")
		(describe "--tp=PREFIX"        "sets the thumbnail image prefix (default: .thumb_)")
		(describe "--sp=PREFIX"        "sets the slide image prefix (default: .slide_)")
		(describe "--up"               "create Up links even in top-level image galleries")
		(describe "--verbose=LEVEL"    "set verbose mode (0: quiet; 1: info; 2: debug)")
		(describe "--www"              "makes all SIGMA files world-readable")
		(describe "--xy=N"             "scale thumbnails to N pixels in their longer dimension")
		(describe "--yslide=N"         "scale slides to the given maximum height")
		(describe "-h, --help"         "print help"))))

       (subsection "Files"
 	       (symbol-table
 	        (describe "/usr/share/sigma/index-template.scm"
 			  "The default index template file.")
 		(describe "/usr/share/sigma/slide-template.scm"
 			  "The default slide template file.")
 		(describe "/usr/share/sigma/sigma.css"
 			  "The default style sheet."))

 	       (p (tt "sigma") " also checks for the existence of a "
 (tt "$HOME/.sigma") " directory where the user can store their own
 templates, overriding the site-wide " (tt "/usr/share/sigma") ". ")))

     (examples (pre #<<EOF

  ## Creates an image gallery using the image files 
  ## found in the current directory and its subdirectories;
  ## uses directory album to write the HTML files and slides;
  ## writes image sizes and captions under the thumbnails on the index pages;
  ## creates and reads .captions file; resizes the slide images to a maximum
  ## height of 500 pixels

  sigma -a -c -u -R --yslide=500 -t album  


EOF
))

     (license
      "Copyright 2007-2009 Ivan Raikov.

Based on the igal program by Eric Pop.  
ISO 9660 image creation code based on code by Walter C. Pelissero.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

A full copy of the GPL license can be found at
<http://www.gnu.org/licenses/>."))))

(if (eggdoc->html doc) (void))
